@@ -23,6 +23,7 @@ import (
 	"github.com/spf13/viper"
 	"github.com/urfave/cli/v2"
 
+	"github.com/tensorchord/envd/pkg/app/telemetry"
 	"github.com/tensorchord/envd/pkg/flag"
 	"github.com/tensorchord/envd/pkg/home"
 	"github.com/tensorchord/envd/pkg/version"
@@ -45,6 +46,18 @@ func New() EnvdApp {
 			Name:  "debug",
 			Usage: "enable debug output in logs",
 		},
+		&cli.BoolFlag{
+			Name:    flag.FlagAnalytics,
+			Usage:   "enable analytics",
+			Value:   true,
+			EnvVars: []string{"ENVD_ANALYTICS"},
+		},
+		&cli.StringFlag{
+			Name:    "analytics-token",
+			Value:   "Kdj4DfmpMoFh9qia2gz9wJq7TdrfVsP7",
+			EnvVars: []string{"ENVD_ANALYTICS_TOKEN"},
+			Hidden:  true,
+		},
 		&cli.StringFlag{
 			Name:   flag.FlagBuildkitdImage,
 			Usage:  "docker image to use for buildkitd",
@@ -57,21 +70,32 @@ func New() EnvdApp {
 			Value:  "tensorchord",
 			Hidden: true,
 		},
+		&cli.StringFlag{
+			Name:    flag.FlagBuildOwner,
+			Usage:   "owner (uid:gid) in the built image",
+			Value:   "",
+			EnvVars: []string{"ENVD_BUILD_OWNER"},
+			Hidden:  true,
+		},
 	}
 
 	internalApp.Commands = []*cli.Command{
 		CommandBootstrap,
+		CommandCreate,
+		CommandCompletion,
 		CommandContext,
 		CommandBuild,
 		CommandDestroy,
 		CommandEnvironment,
 		CommandImage,
 		CommandInit,
+		CommandLogin,
 		CommandPause,
 		CommandPrune,
 		CommandRun,
 		CommandResume,
 		CommandUp,
+		CommandDebug,
 		CommandVersion,
 		CommandTop,
 	}
@@ -81,7 +105,7 @@ func New() EnvdApp {
  Usage:
     envd up --path <path>
 
-    envd run --name <env-name> --command "pip list"{{if .VisibleCommands}}
+    envd build --path <path> --output type=image,name=<image>,push=true{{if .VisibleCommands}}
 
  Build and launch envd environments. Get more information at: https://envd.tensorchord.ai/.
  To get started with using envd, check out the getting started guide: https://envd.tensorchord.ai/guide/getting-started.html.
@@ -97,7 +121,8 @@ func New() EnvdApp {
 
  Global Options:
 	{{range $index, $option := .VisibleFlags}}{{if $index}}
-	{{end}}{{wrap $option.String 6}}{{end}}{{end}}{{end}}`
+	{{end}}{{wrap $option.String 6}}{{end}}{{end}}{{end}}
+`
 
 	// Deal with debug flag.
 	var debugEnabled bool
@@ -114,9 +139,17 @@ func New() EnvdApp {
 			return errors.Wrap(err, "failed to initialize home manager")
 		}
 
+		analytics := context.Bool(flag.FlagAnalytics)
+		if err := telemetry.Initialize(analytics,
+			context.String("analytics-token")); err != nil {
+			return errors.Wrap(err, "failed to create telemetry client")
+		}
+
 		// TODO(gaocegege): Add a config struct to keep them.
 		viper.Set(flag.FlagBuildkitdImage, context.String(flag.FlagBuildkitdImage))
+		viper.Set(flag.FlagBuildOwner, context.String(flag.FlagBuildOwner))
 		viper.Set(flag.FlagDebug, debugEnabled)
+		viper.Set(flag.FlagAnalytics, analytics)
 		viper.Set(flag.FlagDockerOrganization,
 			context.String(flag.FlagDockerOrganization))
 		return nil
