@@ -16,8 +16,9 @@ package app
 
 import (
 	"fmt"
-	"io/ioutil"
+	"os"
 	"path/filepath"
+	"strings"
 
 	"github.com/cockroachdb/errors"
 	"github.com/docker/docker/pkg/namesgenerator"
@@ -33,7 +34,7 @@ import (
 
 var CommandBootstrap = &cli.Command{
 	Name:     "bootstrap",
-	Category: CategoryManagement,
+	Category: CategorySettings,
 	Usage:    "Bootstrap the envd installation",
 	Flags: []cli.Flag{
 		&cli.BoolFlag{
@@ -139,28 +140,28 @@ func sshKey(clicontext *cli.Context) error {
 			}
 		}
 		pub, pri := sshKeyPair[0], sshKeyPair[1]
-		pubKey, err := ioutil.ReadFile(pub)
+		pubKey, err := os.ReadFile(pub)
 		if err != nil {
 			return errors.Wrap(err, "Cannot open public key")
 		}
-		err = ioutil.WriteFile(path, pubKey, 0644)
+		err = os.WriteFile(path, pubKey, 0644)
 		if err != nil {
 			return errors.Wrap(err, "Cannot write public key")
 		}
 
-		priKey, err := ioutil.ReadFile(pri)
+		priKey, err := os.ReadFile(pri)
 		if err != nil {
 			return errors.Wrap(err, "Cannot open private key")
 		}
 
-		err = ioutil.WriteFile(path, priKey, 0600)
+		err = os.WriteFile(path, priKey, 0600)
 		if err != nil {
 			return errors.Wrap(err, "Cannot write private key")
 		}
 		return nil
 
 	default:
-		return errors.Errorf("Invliad ssh-keypair flag")
+		return errors.Errorf("Invalid ssh-keypair flag")
 	}
 }
 
@@ -170,16 +171,22 @@ func autocomplete(clicontext *cli.Context) error {
 		return nil
 	}
 
-	// Because this requires sudo, it should warn and not fail the rest of it.
-	err := ac.InsertBashCompleteEntry()
-	if err != nil {
-		logrus.Warnf("Warning: %s\n", err.Error())
-		err = nil
-	}
-	err = ac.InsertZSHCompleteEntry()
-	if err != nil {
-		logrus.Warnf("Warning: %s\n", err.Error())
-		err = nil
+	shell := os.Getenv("SHELL")
+	if strings.Contains(shell, "zsh") {
+		logrus.Infof("Install zsh autocompletion")
+		if err := ac.InsertZSHCompleteEntry(); err != nil {
+			logrus.Warnf("Warning: %s\n", err.Error())
+		}
+	} else if strings.Contains(shell, "bash") {
+		logrus.Infof("Install bash autocompletion")
+		if err := ac.InsertBashCompleteEntry(); err != nil {
+			logrus.Warnf("Warning: %s\n", err.Error())
+		}
+	} else {
+		logrus.Infof("Install bash autocompletion (fallback from \"%s\")", shell)
+		if err := ac.InsertBashCompleteEntry(); err != nil {
+			logrus.Warnf("Warning: %s\n", err.Error())
+		}
 	}
 
 	logrus.Info("You may have to restart your shell for autocomplete to get initialized (e.g. run \"exec $SHELL\")\n")
@@ -192,14 +199,14 @@ func buildkit(clicontext *cli.Context) error {
 		return nil
 	}
 
-	currentDriver, currentSocket, err := home.GetManager().ContextGetCurrent()
+	c, err := home.GetManager().ContextGetCurrent()
 	if err != nil {
 		return errors.Wrap(err, "failed to get the current context")
 	}
 
 	logrus.Debug("bootstrap the buildkitd container")
 	bkClient, err := buildkitd.NewClient(clicontext.Context,
-		currentDriver, currentSocket, clicontext.String("dockerhub-mirror"))
+		c.Builder, c.BuilderAddress, clicontext.String("dockerhub-mirror"))
 	if err != nil {
 		return errors.Wrap(err, "failed to create buildkit client")
 	}
