@@ -21,14 +21,16 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/urfave/cli/v2"
 
-	"github.com/tensorchord/envd/pkg/docker"
+	"github.com/tensorchord/envd/pkg/app/telemetry"
+	"github.com/tensorchord/envd/pkg/envd"
+	"github.com/tensorchord/envd/pkg/home"
 	sshconfig "github.com/tensorchord/envd/pkg/ssh/config"
 )
 
 var CommandDestroy = &cli.Command{
 	Name:     "destroy",
 	Category: CategoryBasic,
-	Aliases:  []string{"d"},
+	Aliases:  []string{"down", "d"},
 	Usage:    "Destroy the envd environment",
 	Flags: []cli.Flag{
 		&cli.PathFlag{
@@ -56,10 +58,6 @@ func destroy(clicontext *cli.Context) error {
 	if path == "" && name == "" {
 		path = "."
 	}
-	dockerClient, err := docker.NewClient(clicontext.Context)
-	if err != nil {
-		return err
-	}
 	var ctrName string
 	if name != "" {
 		ctrName = name
@@ -70,10 +68,24 @@ func destroy(clicontext *cli.Context) error {
 		}
 		ctrName = filepath.Base(buildContext)
 	}
-	if ctrName, err := dockerClient.Destroy(clicontext.Context, ctrName); err != nil {
+	context, err := home.GetManager().ContextGetCurrent()
+	if err != nil {
+		return errors.Wrap(err, "failed to get the current context")
+	}
+	telemetry.GetReporter().Telemetry("destroy", telemetry.AddField("runner", context.Runner))
+
+	opt := envd.Options{
+		Context: context,
+	}
+	envdEngine, err := envd.New(clicontext.Context, opt)
+	if err != nil {
+		return errors.Wrap(err, "failed to create envd engine")
+	}
+
+	if ctrName, err := envdEngine.Destroy(clicontext.Context, ctrName); err != nil {
 		return errors.Wrapf(err, "failed to destroy the environment: %s", ctrName)
 	} else if ctrName != "" {
-		logrus.Infof("%s is destroyed", ctrName)
+		logrus.Infof("environment(%s) is destroyed", ctrName)
 	}
 
 	if err = sshconfig.RemoveEntry(ctrName); err != nil {
