@@ -17,25 +17,35 @@ package app
 import (
 	"io"
 	"os"
+	"path/filepath"
 
 	"github.com/cockroachdb/errors"
 	"github.com/olekukonko/tablewriter"
 	"github.com/urfave/cli/v2"
 
 	"github.com/tensorchord/envd/pkg/envd"
+	"github.com/tensorchord/envd/pkg/home"
 	"github.com/tensorchord/envd/pkg/types"
 )
 
+func getCurrentDirOrPanic() string {
+	dir, err := os.Getwd()
+	if err != nil {
+		panic(err)
+	}
+	return filepath.Base(dir)
+}
+
 var CommandDescribeEnvironment = &cli.Command{
 	Name:    "describe",
 	Aliases: []string{"d"},
 	Usage:   "Show details about environments, including dependencies and port binding",
 	Flags: []cli.Flag{
 		&cli.StringFlag{
-			Name:     "env",
-			Usage:    "Specify the envd environment to use",
-			Aliases:  []string{"e"},
-			Required: true,
+			Name:    "env",
+			Usage:   "Specify the envd environment to use",
+			Aliases: []string{"e"},
+			Value:   getCurrentDirOrPanic(),
 		},
 	},
 	Action: getEnvironmentDescriptions,
@@ -43,7 +53,14 @@ var CommandDescribeEnvironment = &cli.Command{
 
 func getEnvironmentDescriptions(clicontext *cli.Context) error {
 	envName := clicontext.String("env")
-	envdEngine, err := envd.New(clicontext.Context)
+	context, err := home.GetManager().ContextGetCurrent()
+	if err != nil {
+		return errors.Wrap(err, "failed to get the current context")
+	}
+	opt := envd.Options{
+		Context: context,
+	}
+	envdEngine, err := envd.New(clicontext.Context, opt)
 	if err != nil {
 		return errors.Wrap(err, "failed to create envd engine")
 	}
@@ -86,13 +103,14 @@ func renderPortBindings(w io.Writer, ports []types.PortBinding) {
 	if ports == nil {
 		return
 	}
-	table := createTable(w, []string{"Container Port", "Protocol", "Host IP", "Host Port"})
+	table := createTable(w, []string{"Name", "Container Port", "Protocol", "Host IP", "Host Port"})
 	for _, port := range ports {
-		row := make([]string, 4)
-		row[0] = port.Port
-		row[1] = port.Protocol
-		row[2] = port.HostIP
-		row[3] = port.HostPort
+		row := make([]string, 5)
+		row[0] = port.Name
+		row[1] = port.Port
+		row[2] = port.Protocol
+		row[3] = port.HostIP
+		row[4] = port.HostPort
 		table.Append(row)
 	}
 	table.Render()
