@@ -20,24 +20,28 @@ import (
 	"strconv"
 	"time"
 
+	"github.com/cockroachdb/errors"
 	"github.com/docker/docker/pkg/stringid"
 	"github.com/docker/go-units"
 	"github.com/olekukonko/tablewriter"
 	"github.com/urfave/cli/v2"
 
 	"github.com/tensorchord/envd/pkg/envd"
+	"github.com/tensorchord/envd/pkg/home"
 	"github.com/tensorchord/envd/pkg/types"
 )
 
 var CommandImage = &cli.Command{
 	Name:     "images",
-	Category: CategoryBasic,
+	Category: CategoryManagement,
 	Aliases:  []string{"image"},
 	Usage:    "Manage envd images",
 
 	Subcommands: []*cli.Command{
 		CommandDescribeImage,
 		CommandListImage,
+		CommandPruneImages,
+		CommandRemoveImage,
 	},
 }
 
@@ -49,7 +53,14 @@ var CommandListImage = &cli.Command{
 }
 
 func getImage(clicontext *cli.Context) error {
-	envdEngine, err := envd.New(clicontext.Context)
+	context, err := home.GetManager().ContextGetCurrent()
+	if err != nil {
+		return errors.Wrap(err, "failed to get the current context")
+	}
+	opt := envd.Options{
+		Context: context,
+	}
+	envdEngine, err := envd.New(clicontext.Context, opt)
 	if err != nil {
 		return err
 	}
@@ -79,14 +90,14 @@ func renderImages(imgs []types.EnvdImage, w io.Writer) {
 
 	for _, img := range imgs {
 		envRow := make([]string, 8)
-		envRow[0] = types.GetImageName(img)
+		envRow[0] = img.Name
 		envRow[1] = stringOrNone(img.BuildContext)
 		envRow[2] = strconv.FormatBool(img.GPU)
 		envRow[3] = stringOrNone(img.CUDA)
 		envRow[4] = stringOrNone(img.CUDNN)
-		envRow[5] = stringid.TruncateID(img.ImageSummary.ID)
-		envRow[6] = createdSinceString(img.ImageSummary.Created)
-		envRow[7] = units.HumanSizeWithPrecision(float64(img.ImageSummary.Size), 3)
+		envRow[5] = stringid.TruncateID(img.Digest)
+		envRow[6] = createdSinceString(img.Created)
+		envRow[7] = units.HumanSizeWithPrecision(float64(img.Size), 3)
 		table.Append(envRow)
 	}
 	table.Render()
