@@ -22,15 +22,17 @@ import (
 	ui "github.com/gizak/termui/v3"
 	"github.com/urfave/cli/v2"
 
+	"github.com/tensorchord/envd/pkg/app/telemetry"
 	"github.com/tensorchord/envd/pkg/docker"
 	"github.com/tensorchord/envd/pkg/envd"
+	"github.com/tensorchord/envd/pkg/home"
 	"github.com/tensorchord/envd/pkg/metrics"
 	"github.com/tensorchord/envd/pkg/types"
 )
 
 var CommandTop = &cli.Command{
 	Name:     "top",
-	Category: CategoryBasic,
+	Category: CategoryManagement,
 	Usage:    "Show statistics about the containers managed by the environment.",
 	Flags:    []cli.Flag{},
 	Action:   top,
@@ -42,7 +44,16 @@ func top(clicontext *cli.Context) error {
 		return err
 	}
 
-	envdEngine, err := envd.New(clicontext.Context)
+	context, err := home.GetManager().ContextGetCurrent()
+	if err != nil {
+		return errors.Wrap(err, "failed to get the current context")
+	}
+	opt := envd.Options{
+		Context: context,
+	}
+	telemetry.GetReporter().Telemetry("top", telemetry.AddField("runner", context.Runner))
+
+	envdEngine, err := envd.New(clicontext.Context, opt)
 	if err != nil {
 		return err
 	}
@@ -91,7 +102,6 @@ func initGrid(ctx context.Context, envs []types.EnvdEnvironment, collector metri
 	rows := make([]*metrics.WidgetRow, rowNumber)
 	header := metrics.NewWidgetRow(0)
 	header.Add(metrics.NewNameCol("Name"))
-	header.Add(metrics.NewNameCol("ID"))
 	header.Add(metrics.NewNameCol("CPU"))
 	header.Add(metrics.NewNameCol("Memory"))
 	rows[0] = header
@@ -99,7 +109,6 @@ func initGrid(ctx context.Context, envs []types.EnvdEnvironment, collector metri
 		row := metrics.NewWidgetRow(i + 1)
 		metricsChan := collector.Watch(ctx, env.Name)
 		row.Add(metrics.NewNameCol(env.Name))
-		row.Add(metrics.NewNameCol(env.ID[0:12]))
 		row.Add(metrics.NewCPUCol(metricsChan))
 		row.Add(metrics.NewMEMCol(metricsChan))
 		rows[i+1] = row
