@@ -15,6 +15,7 @@
 package app
 
 import (
+	"fmt"
 	"path/filepath"
 	"time"
 
@@ -22,16 +23,12 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/urfave/cli/v2"
 
-	"github.com/tensorchord/envd/pkg/builder"
-	"github.com/tensorchord/envd/pkg/docker"
-	"github.com/tensorchord/envd/pkg/lang/ir"
-	"github.com/tensorchord/envd/pkg/ssh"
+	buildutil "github.com/tensorchord/envd/pkg/app/build"
+	"github.com/tensorchord/envd/pkg/app/telemetry"
+	"github.com/tensorchord/envd/pkg/envd"
+	"github.com/tensorchord/envd/pkg/home"
 	sshconfig "github.com/tensorchord/envd/pkg/ssh/config"
-	"github.com/tensorchord/envd/pkg/util/netutil"
-)
-
-const (
-	localhost = "127.0.0.1"
+	"github.com/tensorchord/envd/pkg/types"
 )
 
 var CommandUp = &cli.Command{
@@ -103,6 +100,11 @@ var CommandUp = &cli.Command{
 			Usage: "Force rebuild and run the container although the previous container is running",
 			Value: false,
 		},
+		&cli.StringFlag{
+			Name:  "host",
+			Usage: "Assign the host address for environment ssh acesss server listening",
+			Value: envd.Localhost,
+		},
 		// https://github.com/urfave/cli/issues/1134#issuecomment-1191407527
 		&cli.StringFlag{
 			Name:    "export-cache",
@@ -120,9 +122,26 @@ var CommandUp = &cli.Command{
 }
 
 func up(clicontext *cli.Context) error {
-	buildOpt, err := ParseBuildOpt(clicontext)
+	c, err := home.GetManager().ContextGetCurrent()
 	if err != nil {
-		return err
+		return errors.Wrap(err, "failed to get the current context")
+	}
+
+	buildOpt, err := buildutil.ParseBuildOpt(clicontext)
+	if err != nil {
+		return errors.Wrap(err, "failed to parse the build options")
+	}
+
+	// Always push image to registry when envd-server is the runner.
+	if c.Runner == types.RunnerTypeEnvdServer {
+		buildOpt.OutputOpts = fmt.Sprintf("type=image,name=%s,push=true", buildOpt.Tag)
+	}
+	start := time.Now()
+	// Unable to modify sshd host when runner is envd-server.
+	if c.Runner == types.RunnerTypeEnvdServer {
+		if clicontext.String("host") != envd.Localhost {
+			return errors.New("Failed to modify the sshd host when runner is envd-server.")
+		}
 	}
 
 	ctr := filepath.Base(buildOpt.BuildContextDir)
@@ -134,17 +153,21 @@ func up(clicontext *cli.Context) error {
 	})
 	logger.Debug("starting up command")
 
-	builder, err := GetBuilder(clicontext, buildOpt)
+	builder, err := buildutil.GetBuilder(clicontext, buildOpt)
 	if err != nil {
 		return err
 	}
-	if err = InterpretEnvdDef(builder); err != nil {
+	if err = buildutil.InterpretEnvdDef(builder); err != nil {
 		return err
 	}
-	if err = BuildImage(clicontext, builder); err != nil {
+	if err = buildutil.DetectEnvironment(clicontext, buildOpt); err != nil {
+		return err
+	}
+	if err = buildutil.BuildImage(clicontext, builder); err != nil {
 		return err
 	}
 
+	logrus.Debug("start running the environment")
 	// Do not attach GPU if the flag is set.
 	gpuEnable := clicontext.Bool("no-gpu")
 	var gpu bool
@@ -153,70 +176,72 @@ func up(clicontext *cli.Context) error {
 	} else {
 		gpu = builder.GPUEnabled()
 	}
-	numGPUs := builder.NumGPUs()
-
-	sshPortInHost, error := StartEnvd(clicontext, buildOpt, gpu, numGPUs)
-	if error != nil {
-		return error
+	numGPU := 0
+	if gpu {
+		numGPU = 1
 	}
 
+	opt := envd.Options{
+		Context: c,
+	}
+	engine, err := envd.New(clicontext.Context, opt)
+	if err != nil {
+		return errors.Wrap(err, "failed to create the docker client")
+	}
+	startOptions := envd.StartOptions{
+		EnvironmentName: filepath.Base(buildOpt.BuildContextDir),
+		BuildContext:    buildOpt.BuildContextDir,
+		Image:           buildOpt.Tag,
+		NumGPU:          numGPU,
+		Forced:          clicontext.Bool("force"),
+		Timeout:         clicontext.Duration("timeout"),
+		SshdHost:        clicontext.String("host"),
+	}
+	if c.Runner != types.RunnerTypeEnvdServer {
+		startOptions.EngineSource = envd.EngineSource{
+			DockerSource: &envd.DockerSource{
+				Graph:        builder.GetGraph(),
+				MountOptions: clicontext.StringSlice("volume"),
+			},
+		}
+	} else if c.Runner == types.RunnerTypeEnvdServer {
+		startOptions.EnvdServerSource = &envd.EnvdServerSource{}
+	}
+
+	res, err := engine.StartEnvd(clicontext.Context, startOptions)
+	if err != nil {
+		return errors.Wrap(err, "failed to start the envd environment")
+	}
+	logrus.Debugf("container %s is running", res.Name)
+
+	logrus.Debugf("add entry %s to SSH config.", ctr)
+	hostname, err := c.GetSSHHostname(startOptions.SshdHost)
+	if err != nil {
+		return errors.Wrap(err, "failed to get the ssh hostname")
+	}
+
+	eo, err := engine.GenerateSSHConfig(ctr, hostname,
+		clicontext.Path("private-key"), res)
+	if err != nil {
+		return errors.Wrap(err, "failed to get the ssh entry")
+	}
+	if err = sshconfig.AddEntry(eo); err != nil {
+		logrus.Infof("failed to add entry %s to your SSH config file: %s", ctr, err)
+		return errors.Wrap(err, "failed to add entry to your SSH config file")
+	}
+	telemetry.GetReporter().Telemetry(
+		"up",
+		telemetry.AddField("runner", c.Runner),
+		telemetry.AddField("duration", time.Since(start).Seconds()))
+
 	if !detach {
-		opt := ssh.DefaultOptions()
-		opt.PrivateKeyPath = clicontext.Path("private-key")
-		opt.Port = sshPortInHost
-		sshClient, err := ssh.NewClient(opt)
-		if err != nil {
-			return errors.Wrap(err, "failed to create the ssh client")
-		}
-		if err := sshClient.Attach(); err != nil {
-			return errors.Wrap(err, "failed to attach to the container")
+		if err := engine.Attach(ctr, hostname,
+			clicontext.Path("private-key"), res, builder.GetGraph()); err != nil {
+			return errors.Wrap(err, "failed to attach to the ssh target")
 		}
+		logrus.Infof("Detached successfully. You can attach to the container with command `ssh %s.envd`\n",
+			startOptions.EnvironmentName)
 	}
 
 	return nil
 }
-
-func StartEnvd(clicontext *cli.Context, buildOpt builder.Options, gpu bool, numGPUs int) (int, error) {
-	dockerClient, err := docker.NewClient(clicontext.Context)
-	if err != nil {
-		return 0, errors.Wrap(err, "failed to create the docker client")
-	}
-
-	if gpu {
-		nvruntimeExists, err := dockerClient.GPUEnabled(clicontext.Context)
-		if err != nil {
-			return 0, errors.Wrap(err, "failed to check if nvidia-runtime is installed")
-		}
-		if !nvruntimeExists {
-			return 0, errors.New("GPU is required but nvidia container runtime is not installed, please refer to https://docs.nvidia.com/datacenter/cloud-native/container-toolkit/install-guide.html#docker")
-		}
-	}
-
-	sshPortInHost, err := netutil.GetFreePort()
-	if err != nil {
-		return 0, errors.Wrap(err, "failed to get a free port")
-	}
-
-	ctr := filepath.Base(buildOpt.BuildContextDir)
-	force := clicontext.Bool("force")
-	err = dockerClient.CleanEnvdIfExists(clicontext.Context, ctr, force)
-	if err != nil {
-		return 0, errors.Wrap(err, "failed to clean the envd environment")
-	}
-	containerID, containerIP, err := dockerClient.StartEnvd(clicontext.Context,
-		buildOpt.Tag, ctr, buildOpt.BuildContextDir, gpu, numGPUs, sshPortInHost, *ir.DefaultGraph, clicontext.Duration("timeout"),
-		clicontext.StringSlice("volume"))
-	if err != nil {
-		return 0, errors.Wrap(err, "failed to start the envd environment")
-	}
-	logrus.Debugf("container %s is running", containerID)
-
-	logrus.Debugf("Add entry %s to SSH config. at %s", buildOpt.BuildContextDir, containerIP)
-	if err = sshconfig.AddEntry(
-		ctr, localhost, sshPortInHost, clicontext.Path("private-key")); err != nil {
-		logrus.Infof("failed to add entry %s to your SSH config file: %s", ctr, err)
-		return 0, errors.Wrap(err, "failed to add entry to your SSH config file")
-	}
-	return sshPortInHost, nil
-
-}
