@@ -28,8 +28,6 @@ import (
 	gatewayclient "github.com/moby/buildkit/frontend/gateway/client"
 	v1 "github.com/opencontainers/image-spec/specs-go/v1"
 	"github.com/sirupsen/logrus"
-
-	"github.com/tensorchord/envd/pkg/types"
 )
 
 const (
@@ -38,13 +36,14 @@ const (
 )
 
 func ImageConfigStr(labels map[string]string, ports map[string]struct{},
-	entrypoint []string, env []string) (string, error) {
+	entrypoint []string, env []string, user string) (string, error) {
 	pl := platforms.Normalize(platforms.DefaultSpec())
 	img := v1.Image{
 		Config: v1.ImageConfig{
 			Labels:       labels,
+			User:         user,
 			WorkingDir:   "/",
-			Env:          append(env, "PATH="+DefaultPathEnv(pl.OS)),
+			Env:          env,
 			ExposedPorts: ports,
 			Entrypoint:   entrypoint,
 		},
@@ -62,13 +61,6 @@ func ImageConfigStr(labels map[string]string, ports map[string]struct{},
 	return string(data), nil
 }
 
-func DefaultPathEnv(os string) string {
-	if os == "windows" {
-		return types.DefaultPathEnvWindows
-	}
-	return types.DefaultPathEnvUnix
-}
-
 func parseImportCacheCSV(s string) (gatewayclient.CacheOptionsEntry, error) {
 	im := gatewayclient.CacheOptionsEntry{
 		Type:  "",
