@@ -17,7 +17,9 @@ package flag
 const (
 	FlagCacheDir           = "cache-dir"
 	FlagBuildkitdImage     = "buildkitd-image"
+	FlagBuildOwner         = "owner"
 	FlagDebug              = "debug"
+	FlagAnalytics          = "analytics-enabled"
 	FlagBuildContext       = "build-context"
 	FlagDockerOrganization = "docker-organization"
 )
