@@ -11,9 +11,12 @@
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
+
 package metrics
 
-import "math"
+import (
+	"math"
+)
 
 func round(num float64) int {
 	return int(num + math.Copysign(0.5, num))
