@@ -24,43 +24,41 @@ import (
 	"encoding/pem"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net"
 	"os"
-	"strings"
 
-	"github.com/alessio/shellescape"
 	"github.com/cockroachdb/errors"
 	"github.com/sirupsen/logrus"
 	"golang.org/x/crypto/ssh"
 	"golang.org/x/crypto/ssh/agent"
 	"golang.org/x/term"
 
-	"github.com/tensorchord/envd/pkg/lang/ir"
 	"github.com/tensorchord/envd/pkg/ssh/config"
 )
 
 type Client interface {
 	Attach() error
 	ExecWithOutput(cmd string) ([]byte, error)
+	LocalForward(localAddress, targetAddress string) error
 	Close() error
 }
 
 type Options struct {
-	Server         string
-	User           string
-	Port           int
-	Auth           bool
-	PrivateKeyPath string
-	PrivateKeyPwd  string
+	AgentForwarding bool
+	Server          string
+	User            string
+	Port            int
+	Auth            bool
+	PrivateKeyPath  string
+	PrivateKeyPwd   string
 }
 
 func DefaultOptions() Options {
 	return Options{
-		Server:        "localhost",
-		User:          "envd",
-		Auth:          true,
-		PrivateKeyPwd: "",
+		User:            "envd",
+		Auth:            true,
+		PrivateKeyPwd:   "",
+		AgentForwarding: true,
 	}
 }
 
@@ -82,9 +80,18 @@ func GetOptions(entry string) (*Options, error) {
 
 type generalClient struct {
 	cli *ssh.Client
+	opt *Options
 }
 
 func NewClient(opt Options) (Client, error) {
+	logrus.WithFields(logrus.Fields{
+		"user":             opt.User,
+		"port":             opt.Port,
+		"server":           opt.Server,
+		"agent-forwarding": opt.AgentForwarding,
+		"auth":             opt.Auth,
+	}).Debug("ssh to the environment")
+
 	config := &ssh.ClientConfig{
 		User: opt.User,
 		HostKeyCallback: func(hostname string, remote net.Addr, key ssh.PublicKey) error {
@@ -97,7 +104,7 @@ func NewClient(opt Options) (Client, error) {
 
 	if opt.Auth {
 		// read private key file
-		pemBytes, err := ioutil.ReadFile(opt.PrivateKeyPath)
+		pemBytes, err := os.ReadFile(opt.PrivateKeyPath)
 		if err != nil {
 			return nil, errors.Wrapf(
 				err, "reading private key %s failed", opt.PrivateKeyPath)
@@ -120,26 +127,31 @@ func NewClient(opt Options) (Client, error) {
 	}
 	cli = conn
 
-	// open connection to the local agent
-	socketLocation := os.Getenv("SSH_AUTH_SOCK")
-	if socketLocation != "" {
-		agentConn, err := net.Dial("unix", socketLocation)
-		if err != nil {
-			return nil, errors.Wrap(err, "could not connect to local agent socket")
-		}
-		// create agent and add in auth
-		forwardingAgent := agent.NewClient(agentConn)
-		// add callback for forwarding agent to SSH config
-		// XXX - might want to handle reconnects appending multiple callbacks
-		auth := ssh.PublicKeysCallback(forwardingAgent.Signers)
-		config.Auth = append(config.Auth, auth)
-		if err := agent.ForwardToAgent(cli, forwardingAgent); err != nil {
-			return nil, errors.Wrap(err, "forwarding agent to client failed")
+	if opt.AgentForwarding {
+		// open connection to the local agent
+		socketLocation := os.Getenv("SSH_AUTH_SOCK")
+		if socketLocation != "" {
+			agentConn, err := net.Dial("unix", socketLocation)
+			if err != nil {
+				return nil, errors.Wrap(err, "could not connect to local agent socket")
+			}
+			// create agent and add in auth
+			forwardingAgent := agent.NewClient(agentConn)
+			// add callback for forwarding agent to SSH config
+			// might want to handle reconnects appending multiple callbacks
+			auth := ssh.PublicKeysCallback(forwardingAgent.Signers)
+			config.Auth = append(config.Auth, auth)
+			if err := agent.ForwardToAgent(cli, forwardingAgent); err != nil {
+				return nil, errors.Wrap(err, "forwarding agent to client failed")
+			}
+		} else {
+			logrus.Warn("SSH Agent Forwarding is disabled. This will have no impact on your normal use if you do not use the ssh key on the host.")
 		}
 	}
 
 	return &generalClient{
 		cli: cli,
+		opt: &opt,
 	}, nil
 }
 
@@ -157,8 +169,10 @@ func (c generalClient) ExecWithOutput(cmd string) ([]byte, error) {
 	}
 	defer session.Close()
 
-	if err := agent.RequestAgentForwarding(session); err != nil {
-		return nil, errors.Wrap(err, "requesting agent forwarding failed")
+	if c.opt.AgentForwarding {
+		if err := agent.RequestAgentForwarding(session); err != nil {
+			return nil, errors.Wrap(err, "requesting agent forwarding failed")
+		}
 	}
 
 	return session.CombinedOutput(cmd)
@@ -172,8 +186,10 @@ func (c generalClient) Attach() error {
 	}
 	defer session.Close()
 
-	if err := agent.RequestAgentForwarding(session); err != nil {
-		return errors.Wrap(err, "requesting agent forwarding failed")
+	if c.opt.AgentForwarding {
+		if err := agent.RequestAgentForwarding(session); err != nil {
+			return errors.Wrap(err, "requesting agent forwarding failed")
+		}
 	}
 
 	modes := ssh.TerminalModes{
@@ -216,52 +232,72 @@ func (c generalClient) Attach() error {
 		return errors.Newf("request for pseudo terminal failed: %w", err)
 	}
 
-	stdin, err := session.StdinPipe()
-	if err != nil {
-		return errors.Newf("unable to setup stdin for session: %w", err)
-	}
-	Copy(os.Stdin, stdin)
+	session.Stdout = os.Stdout
+	session.Stderr = os.Stderr
+	session.Stdin = os.Stdin
 
-	stdout, err := session.StdoutPipe()
+	logrus.Debug("starting shell")
+	err = session.Shell()
 	if err != nil {
-		return errors.Newf("unable to setup stdout for session: %w", err)
+		return errors.Wrap(err, "starting shell failed")
 	}
-
-	go func() {
-		if _, err := io.Copy(os.Stdout, stdout); err != nil {
-			logrus.Debugf("error while writing to stdOut: %s", err)
+	logrus.Debug("waiting for shell to exit")
+	if err = session.Wait(); err != nil {
+		var ee *ssh.ExitError
+		if ok := errors.As(err, *ee); ok {
+			switch ee.ExitStatus() {
+			case 130:
+				return nil
+			case 137:
+				logrus.Warn(`Insufficient memory.`)
+			}
 		}
-	}()
-
-	stderr, err := session.StderrPipe()
-	if err != nil {
-		return errors.Newf("unable to setup stderr for session: %w", err)
-	}
-
-	go func() {
-		if _, err := io.Copy(os.Stderr, stderr); err != nil {
-			logrus.Debugf("error while writing to stdOut: %s", err)
+		var emr *ssh.ExitMissingError
+		if ok := errors.As(err, &emr); ok {
+			logrus.Debugf("exit status missing: %s", emr)
+			return nil
 		}
-	}()
-
-	// TODO(gaocegege): Refactor it to avoid direct access to DefaultGraph
-	cmd := shellescape.QuoteCommand([]string{ir.DefaultGraph.Shell})
-	logrus.Debugf("executing command over ssh: '%s'", cmd)
-	err = session.Run(cmd)
-	if err == nil {
-		logrus.Infof("Detached successfully. You can attach to the container with command `ssh %s.envd`\n",
-			ir.DefaultGraph.EnvironmentName)
-		return nil
-	}
-	if strings.Contains(err.Error(), "status 130") || strings.Contains(err.Error(), "4294967295") {
-		return nil
-	}
-	if strings.Contains(err.Error(), "exit code 137") || strings.Contains(err.Error(), "exit status 137") {
-		logrus.Warn(`Insufficient memory.`)
+		return errors.Wrap(err, "waiting for session failed")
 	}
 
-	logrus.Debugf("command failed: %s", err)
-	return errors.Wrap(err, "command failed")
+	logrus.Debug("shell exited")
+	return nil
+}
+
+func (c generalClient) LocalForward(localAddress, targetAddress string) error {
+	localListener, err := net.Listen("tcp", localAddress)
+	if err != nil {
+		return errors.Wrap(err, "net.Listen failed")
+	}
+
+	logrus.Debug("begin to forward " + localAddress + " to " + targetAddress)
+	for {
+		localCon, err := localListener.Accept()
+		if err != nil {
+			return errors.Wrap(err, "listen.Accept failed")
+		}
+
+		sshConn, err := c.cli.Dial("tcp", targetAddress)
+		if err != nil {
+			return errors.Wrap(err, "listen.Accept failed")
+		}
+
+		// Copy local.Reader to sshConn.Writer
+		go func() {
+			_, err = io.Copy(sshConn, localCon)
+			if err != nil {
+				logrus.Debugf("io.Copy failed: %v", err)
+			}
+		}()
+
+		// Copy sshConn.Reader to localCon.Writer
+		go func() {
+			_, err = io.Copy(localCon, sshConn)
+			if err != nil {
+				logrus.Debugf("io.Copy failed: %v", err)
+			}
+		}()
+	}
 }
 
 func isTerminal(r io.Reader) (int, bool) {
